==> krita-debuginfo-3.3.2.1-1.tar.xz: usr/src/debug/krita-3.3.2.1-1/plugins/tools/tool_polyline/qrc_polyline.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/krita/krita-3.3.2.1-1.x86_64/src/krita-3.3.2.1/plugins/tools/tool_polyline/tool_polyline_cursor.png
  0x0,0x0,0x1,0x17,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x4,0x3,0x0,0x0,0x0,0x81,0x54,0x67,0xc7,
  0x0,0x0,0x0,0x21,0x50,0x4c,0x54,0x45,0x0,0x0,0x0,0xc6,0xc6,0xc6,0xff,0xff,
  0xff,0x0,0x0,0x0,0xff,0xff,0xff,0x0,0x0,0x0,0x3f,0x3f,0x3f,0xff,0xff,0xff,
  0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,0xff,0x3e,0x2e,0x31,0x51,0x0,0x0,0x0,
  0x9,0x74,0x52,0x4e,0x53,0x0,0x0,0x0,0x1,0x1,0x2,0x4,0x4,0x9,0x35,0xe8,
  0x7c,0x43,0x0,0x0,0x0,0x9c,0x49,0x44,0x41,0x54,0x78,0xda,0xa5,0xd0,0x41,0xa,
  0x2,0x31,0xc,0x5,0xd0,0xf,0x16,0x34,0xae,0xa6,0x5b,0x57,0x1e,0xc5,0x45,0xf1,
  0x4,0x1e,0x6c,0x5c,0xfe,0xac,0xb2,0x6d,0x4f,0x69,0xa3,0x42,0x53,0x86,0x59,0x88,
  0x85,0x12,0xf2,0x68,0x9b,0x4f,0x1,0x9c,0x15,0x71,0x6d,0x21,0x5f,0x34,0x2f,0x3f,
  0x41,0x6b,0xb6,0xf4,0x3d,0x80,0x7c,0x66,0x72,0xdd,0x9c,0xf8,0x67,0xca,0x5e,0xf4,
  0x54,0x6e,0x0,0x8a,0x98,0x17,0x78,0x5f,0xbc,0xdc,0x7,0x5c,0x3f,0x55,0x81,0x9,
  0xc4,0x90,0xbe,0x0,0x8f,0x7a,0x90,0x91,0xef,0x54,0x5d,0x34,0x8e,0xaa,0xf4,0x1b,
  0x51,0x1a,0x19,0xc0,0x1f,0x6d,0x5c,0x67,0x90,0x56,0x39,0x8d,0x15,0xeb,0xd7,0x22,
  0x68,0x37,0xd,0x20,0xd6,0xcd,0x66,0xa0,0x21,0x80,0x82,0xd,0x1,0xc4,0x64,0xf4,
  0x78,0x74,0xa8,0x31,0x78,0x2,0xa8,0x36,0x83,0xf7,0x1,0xa,0xc,0xc7,0xf7,0xb7,
  0xbd,0x0,0xf6,0x2e,0x35,0x6d,0xa4,0x3f,0x13,0x9,0x0,0x0,0x0,0x0,0x49,0x45,
  0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // tool_polyline_cursor.png
  0x0,0x18,
  0x2,0x33,0x17,0x27,
  0x0,0x74,
  0x0,0x6f,0x0,0x6f,0x0,0x6c,0x0,0x5f,0x0,0x70,0x0,0x6f,0x0,0x6c,0x0,0x79,0x0,0x6c,0x0,0x69,0x0,0x6e,0x0,0x65,0x0,0x5f,0x0,0x63,0x0,0x75,0x0,0x72,
  0x0,0x73,0x0,0x6f,0x0,0x72,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/tool_polyline_cursor.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x7c,0x2c,0x70,0x40,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_polyline)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_polyline)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_polyline)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_polyline)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_polyline)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_polyline)(); }
   } dummy;
}

==> krita-debuginfo-3.3.3-1.tar.xz: usr/src/debug/krita-3.3.3-1/plugins/tools/tool_polyline/qrc_polyline.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/krita/krita-3.3.3-1.i686/src/krita-3.3.3/plugins/tools/tool_polyline/tool_polyline_cursor.png
  0x0,0x0,0x1,0x17,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x4,0x3,0x0,0x0,0x0,0x81,0x54,0x67,0xc7,
  0x0,0x0,0x0,0x21,0x50,0x4c,0x54,0x45,0x0,0x0,0x0,0xc6,0xc6,0xc6,0xff,0xff,
  0xff,0x0,0x0,0x0,0xff,0xff,0xff,0x0,0x0,0x0,0x3f,0x3f,0x3f,0xff,0xff,0xff,
  0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,0xff,0x3e,0x2e,0x31,0x51,0x0,0x0,0x0,
  0x9,0x74,0x52,0x4e,0x53,0x0,0x0,0x0,0x1,0x1,0x2,0x4,0x4,0x9,0x35,0xe8,
  0x7c,0x43,0x0,0x0,0x0,0x9c,0x49,0x44,0x41,0x54,0x78,0xda,0xa5,0xd0,0x41,0xa,
  0x2,0x31,0xc,0x5,0xd0,0xf,0x16,0x34,0xae,0xa6,0x5b,0x57,0x1e,0xc5,0x45,0xf1,
  0x4,0x1e,0x6c,0x5c,0xfe,0xac,0xb2,0x6d,0x4f,0x69,0xa3,0x42,0x53,0x86,0x59,0x88,
  0x85,0x12,0xf2,0x68,0x9b,0x4f,0x1,0x9c,0x15,0x71,0x6d,0x21,0x5f,0x34,0x2f,0x3f,
  0x41,0x6b,0xb6,0xf4,0x3d,0x80,0x7c,0x66,0x72,0xdd,0x9c,0xf8,0x67,0xca,0x5e,0xf4,
  0x54,0x6e,0x0,0x8a,0x98,0x17,0x78,0x5f,0xbc,0xdc,0x7,0x5c,0x3f,0x55,0x81,0x9,
  0xc4,0x90,0xbe,0x0,0x8f,0x7a,0x90,0x91,0xef,0x54,0x5d,0x34,0x8e,0xaa,0xf4,0x1b,
  0x51,0x1a,0x19,0xc0,0x1f,0x6d,0x5c,0x67,0x90,0x56,0x39,0x8d,0x15,0xeb,0xd7,0x22,
  0x68,0x37,0xd,0x20,0xd6,0xcd,0x66,0xa0,0x21,0x80,0x82,0xd,0x1,0xc4,0x64,0xf4,
  0x78,0x74,0xa8,0x31,0x78,0x2,0xa8,0x36,0x83,0xf7,0x1,0xa,0xc,0xc7,0xf7,0xb7,
  0xbd,0x0,0xf6,0x2e,0x35,0x6d,0xa4,0x3f,0x13,0x9,0x0,0x0,0x0,0x0,0x49,0x45,
  0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // tool_polyline_cursor.png
  0x0,0x18,
  0x2,0x33,0x17,0x27,
  0x0,0x74,
  0x0,0x6f,0x0,0x6f,0x0,0x6c,0x0,0x5f,0x0,0x70,0x0,0x6f,0x0,0x6c,0x0,0x79,0x0,0x6c,0x0,0x69,0x0,0x6e,0x0,0x65,0x0,0x5f,0x0,0x63,0x0,0x75,0x0,0x72,
  0x0,0x73,0x0,0x6f,0x0,0x72,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/tool_polyline_cursor.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x60,0xd5,0x9a,0x8d,0xa0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_polyline)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_polyline)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_polyline)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_polyline)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_polyline)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_polyline)(); }
   } dummy;
}
